==> gi-assets-algorithm-2.2.4.tgz: package/es/ClusterTable/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
//@ts-nocheck
import { DownloadOutlined } from '@ant-design/icons';
import { SheetComponent } from '@antv/s2-react';
import '@antv/s2-react/dist/style.min.css';
import { Tooltip } from 'antd';
import { isEqual } from 'lodash';
import React, { Component } from 'react';
import { exportCSV, formatFileName } from '../utils/csv';
import './index.less';
import FormattedMessage, { formatMessage } from './locale';
var getConfig = function getConfig(data, clusterTitle, properties) {
  var _a;
  var resData = [];
  (_a = data === null || data === void 0 ? void 0 : data.nodes) === null || _a === void 0 ? void 0 : _a.forEach(function (node) {
    var _a;
    resData.push(Object.assign(Object.assign(Object.assign({}, node.properties || {}), {
      propertyId: (_a = node.properties) === null || _a === void 0 ? void 0 : _a.id
    }), node));
  });
  resData.sort(function (a, b) {
    return Number(a.clusterId) - Number(b.clusterId);
  });
  var dataCfg = {
    fields: {
      rows: ['clusterId', 'id'],
      values: properties || ['nodeType', 'label']
    },
    meta: [{
      field: 'clusterId',
      name: clusterTitle
    }, {
      field: 'id',
      name: 'id'
    }],
    data: resData || []
  };
  return {
    dataCfg: dataCfg,
    resData: resData,
    properties: properties
  };
};
var ClustersTable = /*#__PURE__*/function (_Component) {
  _inherits(ClustersTable, _Component);
  var _super = _createSuper(ClustersTable);
  function ClustersTable() {
    var _this;
    _classCallCheck(this, ClustersTable);
    _this = _super.apply(this, arguments);
    // 交叉表配置项准备
    _this.options = {
      width: 500,
      height: 400,
      hierarchyType: 'grid',
      showDefaultHeaderActionIcon: false,
      style: {
        layoutWidthType: 'compact'
      }
    };
    _this.state = {
      data: null,
      config: null
    };
    _this.download = function () {
      var _this$state$config = _this.state.config,
        _this$state$config2 = _this$state$config === void 0 ? {} : _this$state$config,
        resData = _this$state$config2.resData,
        properties = _this$state$config2.properties;
      var clusterTitle = _this.props.clusterTitle;
      var fileName = formatFileName('cluster_result');
      exportCSV({
        data: resData,
        title: [clusterTitle, formatMessage({
          id: 'node-name'
        })].concat(properties),
        titleForKey: ['clusterId', 'label'].concat(properties)
      }, fileName);
    };
    _this.onRowCellClick = function (_ref) {
      var viewMeta = _ref.viewMeta;
      var query = viewMeta.query,
        spreadsheet = viewMeta.spreadsheet;
      var rowData = spreadsheet.dataSet.getMultiData(query);
      var _ref2 = (rowData === null || rowData === void 0 ? void 0 : rowData[0]) || {},
        id = _ref2.id,
        clusterId = _ref2.clusterId;
      var focusNodeAndHighlightHull = _this.props.focusNodeAndHighlightHull;
      if (focusNodeAndHighlightHull) {
        focusNodeAndHighlightHull(id, clusterId);
      }
    };
    return _this;
  }
  _createClass(ClustersTable, [{
    key: "render",
    value: function render() {
      var _this$state$config3 = this.state.config,
        _this$state$config4 = _this$state$config3 === void 0 ? {} : _this$state$config3,
        dataCfg = _this$state$config4.dataCfg;
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Tooltip, {
        title: /*#__PURE__*/React.createElement(FormattedMessage, {
          id: "download-csv"
        }),
        placement: "topRight"
      }, /*#__PURE__*/React.createElement(DownloadOutlined, {
        style: {
          float: 'right'
        },
        onClick: this.download
      })), /*#__PURE__*/React.createElement("div", {
        className: "community-cluster-table-wrapper"
      }, /*#__PURE__*/React.createElement(SheetComponent, {
        sheetType: "base",
        dataCfg: dataCfg,
        options: this.options || {},
        onRowCellClick: this.onRowCellClick
      })));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      var nextData = nextProps.data,
        clusterTitle = nextProps.clusterTitle,
        properties = nextProps.properties;
      var data = prevState.data;
      if (!isEqual(nextData, data)) {
        var config = getConfig(nextData, clusterTitle, properties);
        return {
          data: data,
          config: config
        };
      }
      return null;
    }
  }]);
  return ClustersTable;
}(Component);
export { ClustersTable as default };

==> gi-assets-algorithm-2.3.12.tgz: package/es/ClusterTable/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
//@ts-nocheck
import { DownloadOutlined } from '@ant-design/icons';
import { SheetComponent } from '@antv/s2-react';
import '@antv/s2-react/dist/style.min.css';
import { Tooltip } from 'antd';
import { isEqual } from 'lodash';
import React, { Component } from 'react';
import { exportCSV, formatFileName } from '../utils/csv';
import './index.less';
import $i18n from '../i18n';
var getConfig = function getConfig(data, clusterTitle, properties) {
  var _a;
  var resData = [];
  (_a = data === null || data === void 0 ? void 0 : data.nodes) === null || _a === void 0 ? void 0 : _a.forEach(function (node) {
    var _a;
    resData.push(Object.assign(Object.assign(Object.assign({}, node.properties || {}), {
      propertyId: (_a = node.properties) === null || _a === void 0 ? void 0 : _a.id
    }), node));
  });
  resData.sort(function (a, b) {
    return Number(a.clusterId) - Number(b.clusterId);
  });
  var dataCfg = {
    fields: {
      rows: ['clusterId', 'id'],
      values: properties || ['nodeType', 'label']
    },
    meta: [{
      field: 'clusterId',
      name: clusterTitle
    }, {
      field: 'id',
      name: 'id'
    }],
    data: resData || []
  };
  return {
    dataCfg: dataCfg,
    resData: resData,
    properties: properties
  };
};
var ClustersTable = /*#__PURE__*/function (_Component) {
  _inherits(ClustersTable, _Component);
  var _super = _createSuper(ClustersTable);
  function ClustersTable() {
    var _this;
    _classCallCheck(this, ClustersTable);
    _this = _super.apply(this, arguments);
    // 交叉表配置项准备
    _this.options = {
      width: 500,
      height: 400,
      hierarchyType: 'grid',
      showDefaultHeaderActionIcon: false,
      style: {
        layoutWidthType: 'compact'
      }
    };
    _this.state = {
      data: null,
      config: null
    };
    _this.download = function () {
      var _this$state$config = _this.state.config,
        _this$state$config2 = _this$state$config === void 0 ? {} : _this$state$config,
        resData = _this$state$config2.resData,
        properties = _this$state$config2.properties;
      var clusterTitle = _this.props.clusterTitle;
      var fileName = formatFileName('cluster_result');
      exportCSV({
        data: resData,
        title: [clusterTitle, $i18n.get({
          id: 'gi-assets-algorithm.src.ClusterTable.NodeName',
          dm: '节点名称'
        })].concat(properties),
        titleForKey: ['clusterId', 'label'].concat(properties)
      }, fileName);
    };
    _this.onRowCellClick = function (_ref) {
      var viewMeta = _ref.viewMeta;
      var query = viewMeta.query,
        spreadsheet = viewMeta.spreadsheet;
      var rowData = spreadsheet.dataSet.getMultiData(query);
      var _ref2 = (rowData === null || rowData === void 0 ? void 0 : rowData[0]) || {},
        id = _ref2.id,
        clusterId = _ref2.clusterId;
      var focusNodeAndHighlightHull = _this.props.focusNodeAndHighlightHull;
      if (focusNodeAndHighlightHull) {
        focusNodeAndHighlightHull(id, clusterId);
      }
    };
    return _this;
  }
  _createClass(ClustersTable, [{
    key: "render",
    value: function render() {
      var _this$state$config3 = this.state.config,
        _this$state$config4 = _this$state$config3 === void 0 ? {} : _this$state$config3,
        dataCfg = _this$state$config4.dataCfg;
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Tooltip, {
        title: $i18n.get({
          id: 'gi-assets-algorithm.src.ClusterTable.DownloadCsv',
          dm: '下载 CSV'
        }),
        placement: "topRight"
      }, /*#__PURE__*/React.createElement(DownloadOutlined, {
        style: {
          float: 'right'
        },
        onClick: this.download
      })), /*#__PURE__*/React.createElement("div", {
        className: "community-cluster-table-wrapper"
      }, /*#__PURE__*/React.createElement(SheetComponent, {
        sheetType: "base",
        dataCfg: dataCfg,
        options: this.options || {},
        onRowCellClick: this.onRowCellClick
      })));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      var nextData = nextProps.data,
        clusterTitle = nextProps.clusterTitle,
        properties = nextProps.properties;
      var data = prevState.data;
      if (!isEqual(nextData, data)) {
        var config = getConfig(nextData, clusterTitle, properties);
        return {
          data: data,
          config: config
        };
      }
      return null;
    }
  }]);
  return ClustersTable;
}(Component);
export { ClustersTable as default };
